module HROOT.Graf.TEllipse
       (TEllipse(..), ITEllipse, upcastTEllipse, downcastTEllipse,
        newTEllipse)
       where
import HROOT.Graf.TEllipse.RawType
import HROOT.Graf.TEllipse.Interface
import HROOT.Graf.TEllipse.Implementation
